"use strict";


{
	////////////////////////////////////////////
	// The plugin ID is how Construct identifies different kinds of plugins.
	// *** NEVER CHANGE THE PLUGIN ID! ***
	// If you change the plugin ID after releasing the plugin, Construct will think it is an entirely different
	// plugin and assume it is incompatible with the old one, and YOU WILL BREAK ALL EXISTING PROJECTS USING THE PLUGIN.
	// Only the plugin name is displayed in the editor, so to rename your plugin change the name but NOT the ID.
	// If you want to completely replace a plugin, make it deprecated (it will be hidden but old projects keep working),
	// and create an entirely new plugin with a different plugin ID.
	const PLUGIN_ID = "ValerypopoffLayouterPlugin";
	////////////////////////////////////////////
	
	const PLUGIN_VERSION = "0.5.1";
	const PLUGIN_CATEGORY = "other";
	
	const PLUGIN_CLASS = SDK.Plugins.ValerypopoffLayouterPlugin = class ValerypopoffLayouterPlugin extends SDK.IPluginBase
	{
		constructor()
		{
			super(PLUGIN_ID);
			
			SDK.Lang.PushContext("plugins." + PLUGIN_ID.toLowerCase());
			
			this._info.SetName(lang(".name"));
			this._info.SetDescription(lang(".description"));
			this._info.SetVersion(PLUGIN_VERSION);
			this._info.SetCategory(PLUGIN_CATEGORY);
			this._info.SetAuthor("Valera Popov");
			this._info.SetHelpUrl(lang(".help-url"));

			// Ignore this: yes	
			this._info.SetPluginType("world");

			this._info.SetIsSingleGlobal(false);
			this._info.SetCanBeBundled(true);
			this._info.SetIsResizable(true);
			this._info.SetIsRotatable(true);
			this._info.SetHasImage(false);
			this._info.SetIsTiled(false);
			this._info.SetIsDeprecated(false);
			this._info.SetSupportsEffects(false);
			this._info.SetMustPreDraw(true);
			
			// Ignore this: yes
			this._info.AddCommonPositionACEs();
			// Ignore this: yes
			this._info.AddCommonSizeACEs();
			// Ignore this: yes
			this._info.AddCommonAngleACEs();
			// Ignore this: yes
			this._info.AddCommonAppearanceACEs();
			// Ignore this: yes
			this._info.AddCommonZOrderACEs();
		
			// Support both the C2 and C3 runtimes
			this._info.SetSupportedRuntimes(["c2", "c3"]);
			
			SDK.Lang.PushContext(".properties");
			
			this._info.SetProperties([
				new SDK.PluginProperty("check", "intially-visible", {
					ignore_this: 0
					,initialValue: 1
					,items: [
					]
				}),
				new SDK.PluginProperty("group", "split-00", {
					ignore_this: 0
					,items: [
					]
				}),
				new SDK.PluginProperty("integer", "elements", {
					ignore_this: 0
					,initialValue: 7
					,items: [
					]
				}),
				new SDK.PluginProperty("integer", "element-width", {
					ignore_this: 0
					,initialValue: 50
					,items: [
					]
				}),
				new SDK.PluginProperty("integer", "element-height", {
					ignore_this: 0
					,initialValue: 30
					,items: [
					]
				}),
				new SDK.PluginProperty("integer", "width-spacing", {
					ignore_this: 0
					,initialValue: 10
					,items: [
					]
				}),
				new SDK.PluginProperty("integer", "height-spacing", {
					ignore_this: 0
					,initialValue: 10
					,items: [
					]
				}),
				new SDK.PluginProperty("group", "split-01", {
					ignore_this: 0
					,items: [
					]
				}),
				new SDK.PluginProperty("combo", "threads-mode", {
					ignore_this: 0
					,initialValue: "fixed-number"
					,items: [
						"fixed-number",
						"viewport-fit"
					]
				}),
				new SDK.PluginProperty("integer", "threads", {
					ignore_this: 0
					,initialValue: 3
					,items: [
					]
				}),
				new SDK.PluginProperty("combo", "fill-width-mode", {
					ignore_this: 0
					,initialValue: "none"
					,items: [
						"none",
						"stretch",
						"space"
					]
				}),
				new SDK.PluginProperty("combo", "fill-height-mode", {
					ignore_this: 0
					,initialValue: "none"
					,items: [
						"none",
						"stretch",
						"space"
					]
				}),
				new SDK.PluginProperty("check", "keep-aspect-ratio", {
					ignore_this: 0
					,initialValue: 1
					,items: [
					]
				}),
				new SDK.PluginProperty("group", "split-02", {
					ignore_this: 0
					,items: [
					]
				}),
				new SDK.PluginProperty("combo", "horizontal-float", {
					ignore_this: 0
					,initialValue: "left"
					,items: [
						"left",
						"center",
						"right"
					]
				}),
				new SDK.PluginProperty("combo", "vertical-float", {
					ignore_this: 0
					,initialValue: "top"
					,items: [
						"top",
						"center",
						"bottom"
					]
				}),
				new SDK.PluginProperty("combo", "flow", {
					ignore_this: 0
					,initialValue: "vertical"
					,items: [
						"vertical",
						"horizontal"
					]
				}),
				new SDK.PluginProperty("combo", "main-axis-direction", {
					ignore_this: 0
					,initialValue: "straight"
					,items: [
						"straight",
						"reversed"
					]
				}),
				new SDK.PluginProperty("combo", "cross-axis-direction", {
					ignore_this: 0
					,initialValue: "straight"
					,items: [
						"straight",
						"reversed"
					]
				})
			]);
			
			SDK.Lang.PopContext();		// .properties
			
			SDK.Lang.PopContext();
		}
	};
	
	PLUGIN_CLASS.Register(PLUGIN_ID, PLUGIN_CLASS);
}